SleepDurationChartWidget class

睡眠时长图表组件 用于显示睡眠时长和各个阶段的详细信息

Inheritance

Constructors

SleepDurationChartWidget({Key? key, required List<SleepDetailChart> details, required DateTime startTime, required DateTime endTime, required double heightUnit, required double titleHeight, required double titleGap, required double xAxisTitleOffset, required double xAxisTitleHeight, required Color bgColor, LineStyle horizontalLineStyle = const LineStyle(width: 5.0, space: 3.0), LineStyle verticalLineStyle = const LineStyle(width: 5.0, space: 3.0), int horizontalLineCount = 8, PaintStyle dividerPaintStyle = const PaintStyle(color: Color(0xFFEEEEEE), strokeWidth: 1.0, style: PaintingStyle.stroke, strokeCap: StrokeCap.round), List<SleepStageStyle>? sleepStageStyles, Map<SleepStage, Color>? stageColors, TextStyle? bottomInfoTextStyle, String dateFormatter(DateTime)?})
const

Properties

bgColor Color
final
bottomInfoTextStyle TextStyle?
final
dateFormatter String Function(DateTime)?
final
details List<SleepDetailChart>
final
dividerPaintStyle PaintStyle
final
endTime DateTime
final
hashCode int
The hash code for this object.
no setterinherited
heightUnit double
final
horizontalLineCount int
final
horizontalLineStyle LineStyle
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sleepStageStyles List<SleepStageStyle>?
final
stageColors Map<SleepStage, Color>?
final
startTime DateTime
final
titleGap double
final
titleHeight double
final
verticalLineStyle LineStyle
final
xAxisTitleHeight double
final
xAxisTitleOffset double
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<SleepDurationChartWidget>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited