SleepStageStyle class

睡眠阶段样式类 用于定义睡眠阶段在图表中的显示样式

Constructors

SleepStageStyle({List<Color>? gradientColor, Color? color, required SleepStageStyleValue value})

Properties

color Color?
final
gradientColor List<Color>?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value SleepStageStyleValue
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited